pub struct BeaconQuery {
pub platform_type: Option<String>,
pub required_capabilities: Vec<i32>,
pub phase: Option<i32>,
pub max_distance_m: Option<f32>,
pub reference_position: Option<Position>,
pub min_health: Option<i32>,
pub min_fuel_minutes: Option<u32>,
}Expand description
Beacon query for discovering nodes
Fields
platform_type: Option<String>Filter by platform type (e.g., “UAV”, “UGV”)
required_capabilities: Vec<i32>Filter by required capabilities
phase: Option<i32>Filter by phase
max_distance_m: Option<f32>Maximum distance in meters (geo-fence)
reference_position: Option<Position>Reference position for distance calculation
min_health: Option<i32>Filter by health status
min_fuel_minutes: Option<u32>Minimum fuel requirement in minutes
Implementations
Sourceimpl BeaconQuery
impl BeaconQuery
Sourcepub fn platform_type(&self) -> &str
pub fn platform_type(&self) -> &str
Returns the value of platform_type, or the default value if platform_type is unset.
Sourcepub fn required_capabilities(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<CapabilityType>>
pub fn required_capabilities( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<CapabilityType>>
Returns an iterator which yields the valid enum values contained in required_capabilities.
Sourcepub fn push_required_capabilities(&mut self, value: CapabilityType)
pub fn push_required_capabilities(&mut self, value: CapabilityType)
Appends the provided enum value to required_capabilities.
Sourcepub fn phase(&self) -> Phase
pub fn phase(&self) -> Phase
Returns the enum value of phase, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn max_distance_m(&self) -> f32
pub fn max_distance_m(&self) -> f32
Returns the value of max_distance_m, or the default value if max_distance_m is unset.
Sourcepub fn min_health(&self) -> HealthStatus
pub fn min_health(&self) -> HealthStatus
Returns the enum value of min_health, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_min_health(&mut self, value: HealthStatus)
pub fn set_min_health(&mut self, value: HealthStatus)
Sets min_health to the provided enum value.
Sourcepub fn min_fuel_minutes(&self) -> u32
pub fn min_fuel_minutes(&self) -> u32
Returns the value of min_fuel_minutes, or the default value if min_fuel_minutes is unset.