#[repr(i32)]pub enum CapabilityType {
Unspecified = 0,
Sensor = 1,
Compute = 2,
Communication = 3,
Mobility = 4,
Payload = 5,
Emergent = 6,
}Expand description
Capability type enumeration
Variants
Unspecified = 0
Sensor = 1
Sensing capabilities (cameras, radar, etc.)
Compute = 2
Computing capabilities
Communication = 3
Communication capabilities
Mobility = 4
Mobility capabilities
Payload = 5
Payload/weapon capabilities
Emergent = 6
Emergent capability from composition
Implementations
Sourceimpl CapabilityType
impl CapabilityType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.