#[repr(i32)]pub enum OperationalStatus {
Unspecified = 0,
Ready = 1,
Active = 2,
Degraded = 3,
Offline = 4,
Maintenance = 5,
}Expand description
Operational status of a platform
Variants
Unspecified = 0
Ready = 1
Ready to accept tasking
Active = 2
Currently executing task
Degraded = 3
Operating with reduced capability
Offline = 4
Not available
Maintenance = 5
Under maintenance
Implementations
Sourceimpl OperationalStatus
impl OperationalStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.