#[repr(i32)]pub enum Scope {
Unspecified = 0,
Individual = 1,
Squad = 2,
Platoon = 3,
Broadcast = 4,
}Expand description
Target scope
Variants
Unspecified = 0
Individual = 1
Single node
Squad = 2
All members of a squad
Platoon = 3
All members of a platoon
Broadcast = 4
All nodes in the network
Implementations
Sourceimpl Scope
impl Scope
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.