#[repr(i32)]pub enum AcknowledgmentPolicy {
Unspecified = 0,
NoAckRequired = 1,
AckRequired = 2,
AckMajorityRequired = 3,
AckLeaderOnly = 4,
}Expand description
Acknowledgment policy
Variants
Unspecified = 0
NoAckRequired = 1
Fire-and-forget
AckRequired = 2
Require acknowledgment from all targets
AckMajorityRequired = 3
Require acks from >50% of targets
AckLeaderOnly = 4
Only squad/platoon leader acks
Implementations
Sourceimpl AcknowledgmentPolicy
impl AcknowledgmentPolicy
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of AcknowledgmentPolicy.
Sourcepub fn from_i32(value: i32) -> Option<AcknowledgmentPolicy>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<AcknowledgmentPolicy>
Use the TryFrom<i32> implementation instead
Converts an i32 to a AcknowledgmentPolicy, or None if value is not a valid variant.
Sourceimpl AcknowledgmentPolicy
impl AcknowledgmentPolicy
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.