#[repr(i32)]pub enum BufferPolicy {
Unspecified = 0,
BufferAndRetry = 1,
DropOnPartition = 2,
RequireImmediateDelivery = 3,
}Expand description
Buffer policy during network partitions
Variants
Unspecified = 0
BufferAndRetry = 1
Queue commands during partition, deliver when reconnected
DropOnPartition = 2
Drop commands if target unreachable
RequireImmediateDelivery = 3
Fail if cannot deliver immediately
Implementations
Sourceimpl BufferPolicy
impl BufferPolicy
Sourceimpl BufferPolicy
impl BufferPolicy
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.