#[repr(i32)]pub enum CommandPriority {
Unspecified = 0,
Routine = 1,
Priority = 2,
Immediate = 3,
Flash = 4,
}Expand description
Command priority levels
Variants
Unspecified = 0
Routine = 1
Standard operations
Priority = 2
Time-sensitive but not critical
Immediate = 3
Requires immediate action
Flash = 4
Mission-critical, override conflicts
Implementations
Sourceimpl CommandPriority
impl CommandPriority
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.