#[repr(i32)]pub enum CommandState {
Unspecified = 0,
StatePending = 1,
StateDelivered = 2,
StateExecuting = 3,
StateCompleted = 4,
StateFailed = 5,
StateCancelled = 6,
StateExpired = 7,
}Expand description
Command state
Variants
Unspecified = 0
StatePending = 1
Command issued, awaiting delivery
StateDelivered = 2
Command delivered to at least one target
StateExecuting = 3
Command being executed
StateCompleted = 4
Command completed successfully
StateFailed = 5
Command failed to execute
StateCancelled = 6
Command cancelled
StateExpired = 7
Command expired (past expires_at time)
Implementations
Sourceimpl CommandState
impl CommandState
Sourceimpl CommandState
impl CommandState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.