#[repr(i32)]pub enum ConflictPolicy {
Unspecified = 0,
LastWriteWins = 1,
HighestPriorityWins = 2,
HighestAuthorityWins = 3,
MergeCompatible = 4,
RejectConflict = 5,
}Expand description
Conflict resolution policy
Variants
Unspecified = 0
LastWriteWins = 1
Most recent command wins
HighestPriorityWins = 2
Command with highest priority wins
HighestAuthorityWins = 3
Command from highest authority level wins
MergeCompatible = 4
Merge if commands are compatible
RejectConflict = 5
Reject conflicting commands
Implementations
Sourceimpl ConflictPolicy
impl ConflictPolicy
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.