#[repr(i32)]pub enum LeaderChangePolicy {
Unspecified = 0,
ReissueFromNewLeader = 1,
ContinueAsIs = 2,
CancelOnLeaderChange = 3,
}Expand description
Leader change policy
Variants
Unspecified = 0
ReissueFromNewLeader = 1
New leader reissues command
ContinueAsIs = 2
Command continues without reissuance
CancelOnLeaderChange = 3
Cancel command when leader changes
Implementations
Sourceimpl LeaderChangePolicy
impl LeaderChangePolicy
Sourcepub fn from_i32(value: i32) -> Option<LeaderChangePolicy>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<LeaderChangePolicy>
Use the TryFrom<i32> implementation instead
Converts an i32 to a LeaderChangePolicy, or None if value is not a valid variant.
Sourceimpl LeaderChangePolicy
impl LeaderChangePolicy
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.