pub struct CommandStatus {
pub command_id: String,
pub state: i32,
pub acknowledgments: Vec<CommandAcknowledgment>,
pub last_updated: Option<Timestamp>,
}Expand description
Command status (for command originators to track)
Fields
command_id: Stringstate: i32acknowledgments: Vec<CommandAcknowledgment>last_updated: Option<Timestamp>Implementations
Sourceimpl CommandStatus
impl CommandStatus
Sourcepub fn state(&self) -> CommandState
pub fn state(&self) -> CommandState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: CommandState)
pub fn set_state(&mut self, value: CommandState)
Sets state to the provided enum value.