#[repr(i32)]pub enum ConfidenceMethod {
Unspecified = 0,
Min = 1,
Max = 2,
Average = 3,
Product = 4,
Custom = 5,
}Expand description
Confidence calculation method
Variants
Unspecified = 0
Min = 1
Minimum of all inputs
Max = 2
Maximum of all inputs
Average = 3
Average of all inputs
Product = 4
Product of all inputs
Custom = 5
Custom calculation (defined in metadata)
Implementations
Sourceimpl ConfidenceMethod
impl ConfidenceMethod
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.