#[repr(i32)]pub enum CompositionRuleType {
Unspecified = 0,
Additive = 1,
Emergent = 2,
Redundant = 3,
Constraint = 4,
}Expand description
Composition rule types (from ADR-004 and E6 experiments)
Variants
Unspecified = 0
Additive = 1
Simple aggregation (e.g., multi-sensor fusion)
Emergent = 2
New capability emerges (e.g., BLOS relay)
Redundant = 3
Backup/failover (e.g., redundant GPS)
Constraint = 4
Constraint satisfaction (e.g., min/max members)
Implementations
Sourceimpl CompositionRuleType
impl CompositionRuleType
Sourcepub fn from_i32(value: i32) -> Option<CompositionRuleType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<CompositionRuleType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a CompositionRuleType, or None if value is not a valid variant.
Sourceimpl CompositionRuleType
impl CompositionRuleType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.