pub struct CompositionRule {
pub id: String,
pub name: String,
pub rule_type: i32,
pub input_capabilities: Vec<i32>,
pub output_capability: Option<Capability>,
pub min_inputs: u32,
pub max_inputs: Option<u32>,
pub confidence_method: i32,
pub metadata_json: String,
pub priority: u32,
pub enabled: bool,
pub created_at: Option<Timestamp>,
}Expand description
Composition rule definition
Fields
id: StringUnique rule identifier
name: StringRule name
rule_type: i32Rule type
input_capabilities: Vec<i32>Input capabilities required
output_capability: Option<Capability>Output capability produced (for emergent rules)
min_inputs: u32Minimum number of inputs required
max_inputs: Option<u32>Maximum number of inputs allowed
confidence_method: i32metadata_json: StringRule metadata (JSON-encoded for flexibility)
priority: u32Rule priority (higher = more important)
enabled: boolWhether this rule is active
created_at: Option<Timestamp>Timestamp when rule was defined
Implementations
Sourceimpl CompositionRule
impl CompositionRule
Sourcepub fn rule_type(&self) -> CompositionRuleType
pub fn rule_type(&self) -> CompositionRuleType
Returns the enum value of rule_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_rule_type(&mut self, value: CompositionRuleType)
pub fn set_rule_type(&mut self, value: CompositionRuleType)
Sets rule_type to the provided enum value.
Sourcepub fn input_capabilities(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<CapabilityType>>
pub fn input_capabilities( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<CapabilityType>>
Returns an iterator which yields the valid enum values contained in input_capabilities.
Sourcepub fn push_input_capabilities(&mut self, value: CapabilityType)
pub fn push_input_capabilities(&mut self, value: CapabilityType)
Appends the provided enum value to input_capabilities.
Sourcepub fn max_inputs(&self) -> u32
pub fn max_inputs(&self) -> u32
Returns the value of max_inputs, or the default value if max_inputs is unset.
Sourcepub fn confidence_method(&self) -> ConfidenceMethod
pub fn confidence_method(&self) -> ConfidenceMethod
Returns the enum value of confidence_method, or the default if the field is set to an invalid enum value.
Sourcepub fn set_confidence_method(&mut self, value: ConfidenceMethod)
pub fn set_confidence_method(&mut self, value: ConfidenceMethod)
Sets confidence_method to the provided enum value.