#[repr(i32)]pub enum AuthorizationLevel {
Unspecified = 0,
Autonomous = 1,
Operator = 2,
Commander = 3,
Higher = 4,
Hold = 5,
}Expand description
Authorization level required for engagement
Variants
Unspecified = 0
Autonomous = 1
Autonomous - system can engage without human approval Typically for defensive countermeasures only
Operator = 2
Operator - requires operator confirmation
Commander = 3
Commander - requires cell/squad commander approval
Higher = 4
Higher authority - requires zone/theater approval
Hold = 5
Weapons hold - no engagement authorized
Implementations
Sourceimpl AuthorizationLevel
impl AuthorizationLevel
Sourcepub fn from_i32(value: i32) -> Option<AuthorizationLevel>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<AuthorizationLevel>
Use the TryFrom<i32> implementation instead
Converts an i32 to a AuthorizationLevel, or None if value is not a valid variant.
Sourceimpl AuthorizationLevel
impl AuthorizationLevel
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.