#[repr(i32)]pub enum EffectorStatus {
Unspecified = 0,
Operational = 1,
Degraded = 2,
Malfunction = 3,
Depleted = 4,
Offline = 5,
Maintenance = 6,
}Expand description
Operational status of effector
Variants
Unspecified = 0
Operational = 1
Fully operational
Degraded = 2
Reduced capability
Malfunction = 3
Malfunction detected
Depleted = 4
Out of ammunition/capacity
Offline = 5
Not available
Maintenance = 6
Under maintenance
Implementations
Sourceimpl EffectorStatus
impl EffectorStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.