#[repr(i32)]pub enum EngagementState {
Unspecified = 0,
Idle = 1,
Tracking = 2,
SolutionValid = 3,
Engaging = 4,
Assessing = 5,
Complete = 6,
}Expand description
Current engagement state
Variants
Unspecified = 0
Idle = 1
No engagement
Tracking = 2
Tracking target
SolutionValid = 3
Firing solution computed
Engaging = 4
Actively engaging
Assessing = 5
Battle damage assessment
Complete = 6
Engagement complete
Implementations
Sourceimpl EngagementState
impl EngagementState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.