pub struct EffectorStateUpdate {
pub platform_id: String,
pub effector: Option<EffectorSpec>,
pub status: i32,
pub timestamp: Option<Timestamp>,
}Expand description
Effector state update message (flows upward with capability advertisements)
Fields
platform_id: StringPlatform this effector belongs to
effector: Option<EffectorSpec>Effector specification with current state
status: i32Current operational status
timestamp: Option<Timestamp>Timestamp of this update
Implementations
Sourceimpl EffectorStateUpdate
impl EffectorStateUpdate
Sourcepub fn status(&self) -> EffectorStatus
pub fn status(&self) -> EffectorStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: EffectorStatus)
pub fn set_status(&mut self, value: EffectorStatus)
Sets status to the provided enum value.