pub enum Target {
NodeId(String),
FormationId(String),
Subordinates(bool),
}Variants
NodeId(String)
Query specific node
FormationId(String)
Query entire formation
Subordinates(bool)
Query all subordinates of requester
Implementations
Sourceimpl Target
impl Target
Sourcepub fn merge(
field: &mut Option<Target>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Target>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.