#[repr(i32)]pub enum DeploymentPolicy {
Unspecified = 0,
Immediate = 1,
Rolling = 2,
Canary = 3,
Scheduled = 4,
}Expand description
Deployment policy for rolling updates
Variants
Unspecified = 0
Immediate = 1
Deploy immediately to all targets
Rolling = 2
Rolling deployment (one at a time)
Canary = 3
Canary deployment (test on subset first)
Scheduled = 4
Deploy at scheduled time
Implementations
Sourceimpl DeploymentPolicy
impl DeploymentPolicy
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.