#[repr(i32)]pub enum DeploymentState {
Unspecified = 0,
Pending = 1,
Downloading = 2,
Verifying = 3,
Installing = 4,
Complete = 5,
Failed = 6,
RolledBack = 7,
}Expand description
State of deployment on a platform
Variants
Unspecified = 0
Pending = 1
Deployment received, not started
Downloading = 2
Currently downloading model
Verifying = 3
Verifying hash/integrity
Installing = 4
Installing/loading model
Complete = 5
Successfully deployed
Failed = 6
Deployment failed
RolledBack = 7
Rolled back to previous version
Implementations
Sourceimpl DeploymentState
impl DeploymentState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.