#[repr(i32)]pub enum ModelType {
Unspecified = 0,
Detector = 1,
Tracker = 2,
DetectorTracker = 3,
Classifier = 4,
Segmentation = 5,
Pose = 6,
Custom = 99,
}Expand description
Type of AI model
Variants
Unspecified = 0
Detector = 1
Object detection model (e.g., YOLO)
Tracker = 2
Object tracking model (e.g., DeepSORT)
DetectorTracker = 3
Combined detection + tracking
Classifier = 4
Classification model
Segmentation = 5
Segmentation model
Pose = 6
Pose estimation model
Custom = 99
Custom/other model type
Implementations
Sourceimpl ModelType
impl ModelType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.