pub struct ModelDeployment {Show 14 fields
pub deployment_id: String,
pub model_id: String,
pub model_version: String,
pub model_type: i32,
pub model_url: String,
pub checksum_sha256: String,
pub file_size_bytes: u64,
pub target_platforms: Vec<String>,
pub deployment_policy: i32,
pub priority: i32,
pub deployed_at: Option<Timestamp>,
pub deployed_by: String,
pub rollback_model_id: String,
pub metadata: Option<ModelMetadata>,
}Expand description
Model deployment message - flows downward from C2 to platforms
Used to distribute AI models from MLOps registries to edge platforms. Supports rolling deployments, hash verification, and rollback.
Fields
deployment_id: StringUnique deployment identifier (e.g., “deploy-2025-001”)
model_id: StringModel identifier (e.g., “yolov8-poi-v2.1”)
model_version: StringModel version string
model_type: i32Type of model being deployed
model_url: StringURL to download the model (HTTPS, S3, or blob reference)
checksum_sha256: StringSHA256 hash of the model file for verification
file_size_bytes: u64Size of the model file in bytes
target_platforms: Vec<String>Target platform IDs for deployment
deployment_policy: i32Deployment policy
priority: i32Priority of this deployment
deployed_at: Option<Timestamp>Timestamp when deployment was initiated
deployed_by: StringIdentity of deployer (e.g., “C2-WebTAK”, “MLOps-Pipeline”)
rollback_model_id: StringPrevious model version for rollback support
metadata: Option<ModelMetadata>Additional model metadata
Implementations
Sourceimpl ModelDeployment
impl ModelDeployment
Sourcepub fn model_type(&self) -> ModelType
pub fn model_type(&self) -> ModelType
Returns the enum value of model_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_model_type(&mut self, value: ModelType)
pub fn set_model_type(&mut self, value: ModelType)
Sets model_type to the provided enum value.
Sourcepub fn deployment_policy(&self) -> DeploymentPolicy
pub fn deployment_policy(&self) -> DeploymentPolicy
Returns the enum value of deployment_policy, or the default if the field is set to an invalid enum value.
Sourcepub fn set_deployment_policy(&mut self, value: DeploymentPolicy)
pub fn set_deployment_policy(&mut self, value: DeploymentPolicy)
Sets deployment_policy to the provided enum value.
Sourcepub fn priority(&self) -> DeploymentPriority
pub fn priority(&self) -> DeploymentPriority
Returns the enum value of priority, or the default if the field is set to an invalid enum value.
Sourcepub fn set_priority(&mut self, value: DeploymentPriority)
pub fn set_priority(&mut self, value: DeploymentPriority)
Sets priority to the provided enum value.