pub struct ModelQuery {
pub model_type: i32,
pub platform_id: String,
pub min_version: String,
pub accelerator_type: i32,
}Expand description
Query for available models
Fields
model_type: i32Filter by model type
platform_id: StringFilter by platform compatibility
min_version: StringFilter by minimum version
accelerator_type: i32Filter by accelerator type
Implementations
Sourceimpl ModelQuery
impl ModelQuery
Sourcepub fn model_type(&self) -> ModelType
pub fn model_type(&self) -> ModelType
Returns the enum value of model_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_model_type(&mut self, value: ModelType)
pub fn set_model_type(&mut self, value: ModelType)
Sets model_type to the provided enum value.
Sourcepub fn accelerator_type(&self) -> AcceleratorType
pub fn accelerator_type(&self) -> AcceleratorType
Returns the enum value of accelerator_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_accelerator_type(&mut self, value: AcceleratorType)
pub fn set_accelerator_type(&mut self, value: AcceleratorType)
Sets accelerator_type to the provided enum value.