#[repr(i32)]pub enum AuthorityLevel {
Unspecified = 0,
Observer = 1,
Advisor = 2,
Supervisor = 3,
Commander = 4,
}Expand description
Authority level for human-machine teaming
Variants
Unspecified = 0
Observer = 1
Can observe only
Advisor = 2
Can provide advice
Supervisor = 3
Can approve/reject actions
Commander = 4
Full command authority
Implementations
Sourceimpl AuthorityLevel
impl AuthorityLevel
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.