#[repr(i32)]pub enum HealthStatus {
Unspecified = 0,
Nominal = 1,
Degraded = 2,
Critical = 3,
Failed = 4,
}Expand description
Health status enumeration
Variants
Unspecified = 0
Nominal = 1
Operating normally
Degraded = 2
Degraded but operational
Critical = 3
Critical failure imminent
Failed = 4
Failed/offline
Implementations
Sourceimpl HealthStatus
impl HealthStatus
Sourceimpl HealthStatus
impl HealthStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.