#[repr(i32)]pub enum OperatorRank {
Show 25 variants
Unspecified = 0,
E1 = 1,
E2 = 2,
E3 = 3,
E4 = 4,
E5 = 5,
E6 = 6,
E7 = 7,
E8 = 8,
E9 = 9,
O1 = 11,
O2 = 12,
O3 = 13,
O4 = 14,
O5 = 15,
O6 = 16,
O7 = 17,
O8 = 18,
O9 = 19,
O10 = 20,
W1 = 21,
W2 = 22,
W3 = 23,
W4 = 24,
W5 = 25,
}Expand description
Operator rank enumeration (military ranks)
Variants
Unspecified = 0
E1 = 1
Enlisted ranks (E1-E9)
E2 = 2
E3 = 3
E4 = 4
E5 = 5
E6 = 6
E7 = 7
E8 = 8
E9 = 9
O1 = 11
Officer ranks (O1-O10)
O2 = 12
O3 = 13
O4 = 14
O5 = 15
O6 = 16
O7 = 17
O8 = 18
O9 = 19
O10 = 20
W1 = 21
Warrant Officer ranks (W1-W5)
W2 = 22
W3 = 23
W4 = 24
W5 = 25
Implementations
Sourceimpl OperatorRank
impl OperatorRank
Sourceimpl OperatorRank
impl OperatorRank
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.