pub struct TargetConvergenceStateProto {
pub target_id: String,
pub intent_id: String,
pub status: i32,
pub remaining_bytes: u64,
pub remaining_items: u32,
pub active_checkpoint: String,
pub blockers: Vec<ConvergenceBlockerProto>,
pub last_updated: Option<Timestamp>,
}Expand description
Per-target convergence state for a sync intent.
Fields
target_id: Stringintent_id: Stringstatus: i32remaining_bytes: u64remaining_items: u32active_checkpoint: Stringblockers: Vec<ConvergenceBlockerProto>last_updated: Option<Timestamp>Implementations
Sourceimpl TargetConvergenceStateProto
impl TargetConvergenceStateProto
Sourcepub fn status(&self) -> ConvergenceStatusEnum
pub fn status(&self) -> ConvergenceStatusEnum
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: ConvergenceStatusEnum)
pub fn set_status(&mut self, value: ConvergenceStatusEnum)
Sets status to the provided enum value.