#[repr(i32)]pub enum CellRole {
Unspecified = 0,
Leader = 1,
Sensor = 2,
Compute = 3,
Relay = 4,
Strike = 5,
Support = 6,
Follower = 7,
}Expand description
Tactical role that a node can fill within a cell
Variants
Unspecified = 0
Leader = 1
Cell leader - coordinates operations
Sensor = 2
Primary sensor/scout - reconnaissance
Compute = 3
Compute node - data processing
Relay = 4
Communications relay - extends range
Strike = 5
Strike platform - primary weapons
Support = 6
Support platform - logistics/medical
Follower = 7
General follower - no specialized role
Implementations
Sourceimpl CellRole
impl CellRole
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.