pub struct RoleCapabilities {
pub role: i32,
pub required_capabilities: Vec<i32>,
pub preferred_capabilities: Vec<i32>,
pub relevant_mos: Vec<String>,
pub description: String,
}Expand description
Role capabilities (required and preferred)
Fields
role: i32The role
required_capabilities: Vec<i32>Required capability types for this role
preferred_capabilities: Vec<i32>Preferred capability types (improve scoring but not required)
relevant_mos: Vec<String>Relevant Military Occupational Specialties (MOS codes)
description: StringHuman-readable role description
Implementations
Sourceimpl RoleCapabilities
impl RoleCapabilities
Sourcepub fn role(&self) -> CellRole
pub fn role(&self) -> CellRole
Returns the enum value of role, or the default if the field is set to an invalid enum value.
Sourcepub fn required_capabilities(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<CapabilityType>>
pub fn required_capabilities( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<CapabilityType>>
Returns an iterator which yields the valid enum values contained in required_capabilities.
Sourcepub fn push_required_capabilities(&mut self, value: CapabilityType)
pub fn push_required_capabilities(&mut self, value: CapabilityType)
Appends the provided enum value to required_capabilities.
Sourcepub fn preferred_capabilities(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<CapabilityType>>
pub fn preferred_capabilities( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<CapabilityType>>
Returns an iterator which yields the valid enum values contained in preferred_capabilities.
Sourcepub fn push_preferred_capabilities(&mut self, value: CapabilityType)
pub fn push_preferred_capabilities(&mut self, value: CapabilityType)
Appends the provided enum value to preferred_capabilities.