pub struct RoleChangeEvent {
pub cell_id: String,
pub node_id: String,
pub previous_role: i32,
pub new_role: i32,
pub change_reason: String,
pub changed_at: Option<Timestamp>,
}Expand description
Role change event
Fields
cell_id: StringCell ID
node_id: StringNode ID whose role changed
previous_role: i32Previous role
new_role: i32New role
change_reason: StringReason for change
changed_at: Option<Timestamp>Timestamp of change
Implementations
Sourceimpl RoleChangeEvent
impl RoleChangeEvent
Sourcepub fn previous_role(&self) -> CellRole
pub fn previous_role(&self) -> CellRole
Returns the enum value of previous_role, or the default if the field is set to an invalid enum value.
Sourcepub fn set_previous_role(&mut self, value: CellRole)
pub fn set_previous_role(&mut self, value: CellRole)
Sets previous_role to the provided enum value.
Sourcepub fn new_role(&self) -> CellRole
pub fn new_role(&self) -> CellRole
Returns the enum value of new_role, or the default if the field is set to an invalid enum value.
Sourcepub fn set_new_role(&mut self, value: CellRole)
pub fn set_new_role(&mut self, value: CellRole)
Sets new_role to the provided enum value.