#[repr(i32)]pub enum HierarchyLevel {
Unspecified = 0,
Squad = 1,
Platoon = 2,
Company = 3,
Battalion = 4,
Brigade = 5,
Division = 6,
}Expand description
Hierarchy level for organizational units
Variants
Implementations
Sourceimpl HierarchyLevel
impl HierarchyLevel
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.