#[repr(i32)]pub enum SensorModality {
Unspecified = 0,
Eo = 1,
Ir = 2,
Mwir = 3,
Lwir = 4,
Radar = 5,
Lidar = 6,
Sar = 7,
Multispectral = 8,
Acoustic = 9,
}Expand description
Sensor modality / imaging type
Variants
Unspecified = 0
Eo = 1
Electro-Optical (visible light)
Ir = 2
Infrared / Thermal (general)
Mwir = 3
Mid-Wave Infrared (3-5 micron)
Lwir = 4
Long-Wave Infrared (8-14 micron)
Radar = 5
Radar (active RF)
Lidar = 6
LiDAR (laser scanning)
Sar = 7
Synthetic Aperture Radar
Multispectral = 8
Multi-spectral / Hyperspectral
Acoustic = 9
Acoustic / Sonar
Implementations
Sourceimpl SensorModality
impl SensorModality
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.