#[repr(i32)]pub enum SensorStatus {
Unspecified = 0,
Operational = 1,
Degraded = 2,
Calibrating = 3,
Stowed = 4,
Offline = 5,
}Expand description
Sensor status for health monitoring
Variants
Unspecified = 0
Operational = 1
Normal operation
Degraded = 2
Reduced capability
Calibrating = 3
Calibration in progress
Stowed = 4
Gimbal stowed/protected
Offline = 5
Not available
Implementations
Sourceimpl SensorStatus
impl SensorStatus
Sourceimpl SensorStatus
impl SensorStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.