pub struct SensorStateUpdate {
pub platform_id: String,
pub sensor: Option<SensorSpec>,
pub status: i32,
pub timestamp: Option<Timestamp>,
}Expand description
Sensor state update message (flows upward with capability advertisements)
Fields
platform_id: StringPlatform this sensor belongs to
sensor: Option<SensorSpec>Sensor specification with current state
status: i32Current operational status
timestamp: Option<Timestamp>Timestamp of this update
Implementations
Sourceimpl SensorStateUpdate
impl SensorStateUpdate
Sourcepub fn status(&self) -> SensorStatus
pub fn status(&self) -> SensorStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: SensorStatus)
pub fn set_status(&mut self, value: SensorStatus)
Sets status to the provided enum value.