#[repr(i32)]pub enum TaskControlAction {
TaskControlUnspecified = 0,
TaskControlPause = 1,
TaskControlResume = 2,
TaskControlCancel = 3,
TaskControlUpdate = 4,
}Expand description
Task control actions
Variants
TaskControlUnspecified = 0
TaskControlPause = 1
Pause task execution
TaskControlResume = 2
Resume paused task
TaskControlCancel = 3
Cancel task
TaskControlUpdate = 4
Update task parameters
Implementations
Sourceimpl TaskControlAction
impl TaskControlAction
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.