#[repr(i32)]pub enum TaskPriority {
Unspecified = 0,
Low = 1,
Normal = 2,
High = 3,
Critical = 4,
}Expand description
Task priority
Variants
Unspecified = 0
Low = 1
Background task
Normal = 2
Standard priority
High = 3
Time-sensitive
Critical = 4
Mission-critical, preempt other tasks
Implementations
Sourceimpl TaskPriority
impl TaskPriority
Sourceimpl TaskPriority
impl TaskPriority
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.