#[repr(i32)]pub enum TrackReportMode {
Unspecified = 0,
TrackReportAll = 1,
TrackReportSignificant = 2,
TrackReportOnChange = 3,
}Expand description
Track reporting mode
Variants
Unspecified = 0
TrackReportAll = 1
Report every track update
TrackReportSignificant = 2
Only report significant changes
TrackReportOnChange = 3
Report on state changes (new, lost, etc.)
Implementations
Sourceimpl TrackReportMode
impl TrackReportMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.