pub struct ChipoutConfig {
pub format: i32,
pub jpeg_quality: u32,
pub max_dimension: u32,
pub padding_percent: f32,
pub include_full_frame: bool,
pub full_frame_jpeg_quality: u32,
pub full_frame_max_dimension: u32,
}Expand description
Chipout (image extraction) configuration
Fields
format: i32Image format for chipouts
jpeg_quality: u32JPEG quality (1-100, only applies to JPEG format)
max_dimension: u32Maximum dimension (width or height) for chipout images Image will be scaled down if larger
padding_percent: f32Padding around detection bbox (percentage, e.g., 0.1 = 10%)
include_full_frame: boolInclude full frame with chipout? (for context)
full_frame_jpeg_quality: u32Full frame JPEG quality (typically lower than chipout)
full_frame_max_dimension: u32Maximum full frame dimension
Implementations
Sourceimpl ChipoutConfig
impl ChipoutConfig
Sourcepub fn format(&self) -> ImageFormat
pub fn format(&self) -> ImageFormat
Returns the enum value of format, or the default if the field is set to an invalid enum value.
Sourcepub fn set_format(&mut self, value: ImageFormat)
pub fn set_format(&mut self, value: ImageFormat)
Sets format to the provided enum value.