pub struct TaskQuery {
pub platform_id: String,
pub states: Vec<i32>,
pub min_priority: i32,
pub include_statistics: bool,
}Expand description
Query for tasks
Fields
platform_id: StringFilter by platform ID
states: Vec<i32>Filter by task state
min_priority: i32Filter by priority
include_statistics: boolInclude task statistics
Implementations
Sourceimpl TaskQuery
impl TaskQuery
Sourcepub fn states(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TaskState>>
pub fn states( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TaskState>>
Returns an iterator which yields the valid enum values contained in states.
Sourcepub fn push_states(&mut self, value: TaskState)
pub fn push_states(&mut self, value: TaskState)
Appends the provided enum value to states.
Sourcepub fn min_priority(&self) -> TaskPriority
pub fn min_priority(&self) -> TaskPriority
Returns the enum value of min_priority, or the default if the field is set to an invalid enum value.
Sourcepub fn set_min_priority(&mut self, value: TaskPriority)
pub fn set_min_priority(&mut self, value: TaskPriority)
Sets min_priority to the provided enum value.