pub struct TrackReportingConfig {
pub mode: i32,
pub min_position_change_m: f32,
pub min_confidence_change: f32,
pub max_report_interval_s: f32,
}Expand description
Track reporting configuration
Fields
mode: i32Report all track updates or only significant changes
min_position_change_m: f32For SIGNIFICANT_ONLY mode: minimum position change (meters)
min_confidence_change: f32For SIGNIFICANT_ONLY mode: minimum confidence change
max_report_interval_s: f32Maximum time between track reports even if no significant change
Implementations
Sourceimpl TrackReportingConfig
impl TrackReportingConfig
Sourcepub fn mode(&self) -> TrackReportMode
pub fn mode(&self) -> TrackReportMode
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: TrackReportMode)
pub fn set_mode(&mut self, value: TrackReportMode)
Sets mode to the provided enum value.