#[repr(i32)]pub enum SourceType {
Unspecified = 0,
Sensor = 1,
AiModel = 2,
Human = 3,
Fused = 4,
}Expand description
Type of track source
Variants
Unspecified = 0
Sensor = 1
Raw sensor (radar, camera, etc.)
AiModel = 2
AI/ML model processing
Human = 3
Human observer
Fused = 4
Fused from multiple sources
Implementations
Sourceimpl SourceType
impl SourceType
Sourceimpl SourceType
impl SourceType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.