#[repr(i32)]pub enum TrackState {
Unspecified = 0,
Tentative = 1,
Confirmed = 2,
Lost = 3,
Dropped = 4,
}Expand description
Track state
Variants
Unspecified = 0
Tentative = 1
New track, not yet confirmed
Confirmed = 2
Track confirmed with multiple observations
Lost = 3
Track lost (no recent observations)
Dropped = 4
Track dropped (stale, no longer tracked)
Implementations
Sourceimpl TrackState
impl TrackState
Sourceimpl TrackState
impl TrackState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.