pub struct TrackUpdate {
pub update_type: i32,
pub track: Option<Track>,
pub previous_track_id: String,
pub timestamp: Option<Timestamp>,
}Expand description
Track update message - flows upward from platforms
Used to report new tracks, update existing tracks, or report track drops. This is the primary ISR product message.
Fields
update_type: i32Update type
track: Option<Track>The track being reported/updated
previous_track_id: StringPrevious track ID (for track merges)
timestamp: Option<Timestamp>Timestamp of this update
Implementations
Sourceimpl TrackUpdate
impl TrackUpdate
Sourcepub fn update_type(&self) -> UpdateType
pub fn update_type(&self) -> UpdateType
Returns the enum value of update_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_update_type(&mut self, value: UpdateType)
pub fn set_update_type(&mut self, value: UpdateType)
Sets update_type to the provided enum value.