#[repr(i32)]pub enum PropagationMode {
PropagationFull = 0,
PropagationSummary = 1,
PropagationQuery = 2,
PropagationLocal = 3,
}Expand description
How events propagate through the hierarchy
Variants
PropagationFull = 0
Forward complete event upward immediately
PropagationSummary = 1
Aggregate events at each echelon, forward summaries
PropagationQuery = 2
Store locally, respond to queries from higher echelons
PropagationLocal = 3
No propagation, local storage only
Implementations
Sourceimpl PropagationMode
impl PropagationMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.