#[repr(i32)]pub enum AcceleratorType {
Unspecified = 0,
Cpu = 1,
Cuda = 2,
Tensorrt = 3,
Jetson = 4,
Coral = 5,
Openvino = 6,
}Expand description
Accelerator type for inference
Variants
Unspecified = 0
Cpu = 1
CPU-only
Cuda = 2
NVIDIA CUDA GPU
Tensorrt = 3
NVIDIA TensorRT
Jetson = 4
NVIDIA Jetson (Orin, Xavier, etc.)
Coral = 5
Google Coral TPU
Openvino = 6
Intel OpenVINO
Implementations
Sourceimpl AcceleratorType
impl AcceleratorType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.