pub struct AlertProduct {
pub alert_type: i32,
pub severity: i32,
pub message: String,
pub threshold: f32,
pub actual_value: f32,
pub related_ids: Vec<String>,
pub acknowledged: bool,
}Expand description
Alert or anomaly detection
Fields
alert_type: i32Alert type
severity: i32Severity level
message: StringAlert message/description
threshold: f32Threshold that was crossed (if applicable)
actual_value: f32Related entity IDs
acknowledged: boolIs this alert acknowledged?
Implementations
Sourceimpl AlertProduct
impl AlertProduct
Sourcepub fn alert_type(&self) -> AlertType
pub fn alert_type(&self) -> AlertType
Returns the enum value of alert_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_alert_type(&mut self, value: AlertType)
pub fn set_alert_type(&mut self, value: AlertType)
Sets alert_type to the provided enum value.
Sourcepub fn severity(&self) -> AlertSeverity
pub fn severity(&self) -> AlertSeverity
Returns the enum value of severity, or the default if the field is set to an invalid enum value.
Sourcepub fn set_severity(&mut self, value: AlertSeverity)
pub fn set_severity(&mut self, value: AlertSeverity)
Sets severity to the provided enum value.