pub struct RegistryTargetProto {
pub id: String,
pub endpoint: String,
pub tier: i32,
pub metadata: HashMap<String, String>,
}Expand description
OCI registry endpoint with tier and auth configuration.
Fields
id: Stringendpoint: Stringtier: i32metadata: HashMap<String, String>Implementations
Sourceimpl RegistryTargetProto
impl RegistryTargetProto
Sourcepub fn tier(&self) -> RegistryTier
pub fn tier(&self) -> RegistryTier
Returns the enum value of tier, or the default if the field is set to an invalid enum value.
Sourcepub fn set_tier(&mut self, value: RegistryTier)
pub fn set_tier(&mut self, value: RegistryTier)
Sets tier to the provided enum value.