pub struct SyncIntent {
pub intent_id: String,
pub source: String,
pub targets: Vec<String>,
pub repositories: Vec<String>,
pub policy_class: i32,
pub priority: i32,
pub wave: u32,
pub require_referrers: Vec<String>,
pub pin_digests: Vec<String>,
pub created_at: Option<Timestamp>,
}Expand description
Declarative sync request from operator or formation leader.
Fields
intent_id: Stringsource: Stringtargets: Vec<String>repositories: Vec<String>policy_class: i32priority: i32wave: u32require_referrers: Vec<String>pin_digests: Vec<String>created_at: Option<Timestamp>Implementations
Sourceimpl SyncIntent
impl SyncIntent
Sourcepub fn policy_class(&self) -> DdilPolicyClass
pub fn policy_class(&self) -> DdilPolicyClass
Returns the enum value of policy_class, or the default if the field is set to an invalid enum value.
Sourcepub fn set_policy_class(&mut self, value: DdilPolicyClass)
pub fn set_policy_class(&mut self, value: DdilPolicyClass)
Sets policy_class to the provided enum value.
Sourcepub fn priority(&self) -> SyncPriority
pub fn priority(&self) -> SyncPriority
Returns the enum value of priority, or the default if the field is set to an invalid enum value.
Sourcepub fn set_priority(&mut self, value: SyncPriority)
pub fn set_priority(&mut self, value: SyncPriority)
Sets priority to the provided enum value.