pub struct ProductDelivery {
pub product_types: Vec<i32>,
pub chipout_triggers: Vec<i32>,
pub chipout_config: Option<ChipoutConfig>,
pub track_reporting: Option<TrackReportingConfig>,
pub batching: Option<BatchingConfig>,
}Expand description
Product delivery configuration
Fields
product_types: Vec<i32>Which product types to generate
chipout_triggers: Vec<i32>When to generate image chipouts
chipout_config: Option<ChipoutConfig>Chipout configuration
track_reporting: Option<TrackReportingConfig>Track update frequency
batching: Option<BatchingConfig>Batching configuration (for bandwidth optimization)
Implementations
Sourceimpl ProductDelivery
impl ProductDelivery
Sourcepub fn product_types(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ProductType>>
pub fn product_types( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ProductType>>
Returns an iterator which yields the valid enum values contained in product_types.
Sourcepub fn push_product_types(&mut self, value: ProductType)
pub fn push_product_types(&mut self, value: ProductType)
Appends the provided enum value to product_types.
Sourcepub fn chipout_triggers(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ImageTrigger>>
pub fn chipout_triggers( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ImageTrigger>>
Returns an iterator which yields the valid enum values contained in chipout_triggers.
Sourcepub fn push_chipout_triggers(&mut self, value: ImageTrigger)
pub fn push_chipout_triggers(&mut self, value: ImageTrigger)
Appends the provided enum value to chipout_triggers.